@@ -1,17 +1,11 @@
 import sqlite3
 import sys
 from collections.abc import Hashable
-from typing import Callable, Generic, Optional, Tuple, TypeVar, Union, cast
+from itertools import chain
+from typing import Callable, Generic, Optional, Tuple, TypeVar, Union, cast, overload
 
 if sys.version_info >= (3, 9):
-    from collections.abc import (
-        Iterable,
-        Iterator,
-        Mapping,
-        MutableMapping,
-        MutableSet,
-        Reversible,
-    )
+    from collections.abc import Iterable, Iterator, Mapping, MutableMapping, Reversible
 else:
     from typing import Iterable, Iterator, Mapping, MutableMapping
 if sys.version_info >= (3, 8):
@@ -35,7 +29,7 @@ class _Dict(Generic[KT, VT], SqliteCollectionBase[VT], MutableMapping[KT, VT]):
         key_deserializer: Optional[Callable[[bytes], KT]] = None,
         persist: bool = True,
         rebuild_strategy: RebuildStrategy = RebuildStrategy.CHECK_WITH_FIRST_ELEMENT,
-        data: Optional[Mapping[KT, VT]] = None,
+        data: Optional[Union[Iterable[Tuple[KT, VT]], Mapping[KT, VT]]] = None,
     ) -> None:
         super(_Dict, self).__init__(
             connection=connection,
@@ -54,6 +48,7 @@ class _Dict(Generic[KT, VT], SqliteCollectionBase[VT], MutableMapping[KT, VT]):
         )
         self._initialize(commit=True)
         if data is not None:
+            self.clear()
             self.update(data)
 
     @property
@@ -118,12 +113,15 @@ class _Dict(Generic[KT, VT], SqliteCollectionBase[VT], MutableMapping[KT, VT]):
         if commit:
             self.connection.commit()
 
-    def _is_hashable(self, key: KT) -> bool:
+    def _is_hashable(self, key: object) -> bool:
         return isinstance(key, Hashable)
 
     def _delete_single_record_by_serialized_key(self, cur: sqlite3.Cursor, serialized_key: bytes) -> None:
         cur.execute(f"DELETE FROM {self.table_name} WHERE serialized_key=?", (serialized_key,))
 
+    def _delete_all_records(self, cur: sqlite3.Cursor) -> None:
+        cur.execute(f"DELETE FROM {self.table_name}")
+
     def _is_serialized_key_in(self, cur: sqlite3.Cursor, serialized_key: bytes) -> bool:
         cur.execute(f"SELECT 1 FROM {self.table_name} WHERE serialized_key=?", (serialized_key,))
         return len(list(cur)) > 0
@@ -252,6 +250,34 @@ class _Dict(Generic[KT, VT], SqliteCollectionBase[VT], MutableMapping[KT, VT]):
             self.deserialize(serialized_item[1]),
         )
 
+    @overload
+    def update(self, __other: Mapping[KT, VT], **kwargs: VT) -> None:
+        ...
+
+    @overload
+    def update(self, __other: Iterable[Tuple[KT, VT]], **kwargs: VT) -> None:
+        ...
+
+    @overload
+    def update(self, **kwargs: VT) -> None:
+        ...
+
+    def update(self, __other: Optional[Union[Iterable[Tuple[KT, VT]], Mapping[KT, VT]]] = None, **kwargs: VT) -> None:
+        cur = self.connection.cursor()
+        for k, v in chain(dict({} if __other is None else __other).items(), cast(Mapping[KT, VT], kwargs).items()):
+            self._upsert(cur, self.serialize_key(k), self.serialize(v))
+        self.connection.commit()
+
+    def clear(self) -> None:
+        cur = self.connection.cursor()
+        self._delete_all_records(cur)
+        self.connection.commit()
+
+    def __contains__(self, o: object) -> bool:
+        if not self._is_hashable(o):
+            raise TypeError(f"unhashable type: {type(o).__name__}")
+        return self._is_serialized_key_in(self.connection.cursor(), self.serialize_key(cast(KT, o)))
+
 
 if sys.version_info >= (3, 8):
 
